<?php

namespace PdToolKit\Exceptions;

use Exception;
use Throwable;
use Illuminate\Http\JsonResponse;

class ApiException extends Exception
{
    /**
     * 返回到接口的验证码
     * @var int $response_code
     */
    protected $response_code = 400000;

    /**
     * ApiException constructor.
     * @param string $message
     * @param Throwable|null $previous
     */
    public function __construct(string $message, Throwable $previous = null)
    {
        parent::__construct($message, $this->response_code, $previous);
    }

    public static function fromException(Exception $e)
    {
        return new ApiException($e->getMessage(), $e);
    }

    /**
     * @return int
     */
    public function getResponseCode()
    {
        return $this->response_code;
    }

    /**
     * @return JsonResponse
     */
    public function render(): JsonResponse
    {
        return new JsonResponse([
            'message' => $this->getMessage(),
            'code' => $this->getResponseCode(),
            'data' => new \stdClass(),
        ]);
    }
}
